@@ -20,7 +20,7 @@
 #'
 #' @seealso [gisco_coastallines]
 #'
-#' @examples
+#' @examplesIf gisco_check_access()
 #' coast <- gisco_get_coastallines()
 #'
 #' library(ggplot2)
@@ -45,15 +45,9 @@ gisco_get_coastallines <- function(year = "2016",
   ext <- "geojson"
 
   api_entry <- gsc_api_url(
-    id_giscoR = "coastallines",
-    year = year,
-    epsg = epsg,
-    resolution = resolution,
-    spatialtype = NULL,
-    ext = ext,
-    nuts_level = NULL,
-    level = NULL,
-    verbose = verbose
+    id_giscoR = "coastallines", year = year,
+    epsg = epsg, resolution = resolution, spatialtype = NULL, ext = ext,
+    nuts_level = NULL, level = NULL, verbose = verbose
   )
 
   filename <- basename(api_entry)
@@ -75,21 +69,20 @@ gisco_get_coastallines <- function(year = "2016",
   if (dwnload) {
     if (cache) {
       # Guess source to load
-      namefileload <-
-        gsc_api_cache(
-          api_entry,
-          filename,
-          cache_dir,
-          update_cache,
-          verbose
-        )
+      namefileload <- gsc_api_cache(
+        api_entry, filename, cache_dir,
+        update_cache, verbose
+      )
     } else {
       namefileload <- api_entry
     }
 
+    if (is.null(namefileload)) {
+      return(NULL)
+    }
+
     # Load - geojson only so far
-    data_sf <-
-      gsc_api_load(namefileload, epsg, ext, cache, verbose)
+    data_sf <- gsc_api_load(namefileload, epsg, ext, cache, verbose)
   }
   return(data_sf)
 }
