@@ -27,31 +27,7 @@
 #' \donttest{
 #'
 #' health_BEL <- gisco_get_healthcare(country = "Belgium")
-#' # If downloaded
-#'
-#' if (!is.null(health_BEL)) {
-#'   health_BEL[health_BEL$public_private == "", ]$public_private <- "unknown"
-#'
-#'   BEL <- gisco_get_nuts(country = "Belgium", nuts_level = 2)
-#'
-#'   library(ggplot2)
-#'
-#'   ggplot(BEL) +
-#'     geom_sf(fill = "white", color = "grey80") +
-#'     geom_sf(
-#'       data = health_BEL, aes(color = public_private),
-#'       alpha = 0.5, size = 3
-#'     ) +
-#'     theme_bw() +
-#'     labs(
-#'       title = "Healthcare in Belgium",
-#'       subtitle = "NUTS 2",
-#'       fill = "type",
-#'       caption = paste0(gisco_attributions())
-#'     ) +
-#'     scale_color_manual(name = "type", values = hcl.colors(3, "Berlin")) +
-#'     theme_minimal()
-#' }
+#' health_BEL
 #' }
 #' @export
 gisco_get_healthcare <- function(cache = TRUE,
@@ -63,7 +39,10 @@ gisco_get_healthcare <- function(cache = TRUE,
   epsg <- "4326"
   ext <- "gpkg"
 
-  api_entry <- "https://gisco-services.ec.europa.eu/pub/healthcare/gpkg/EU/EU.gpkg"
+  api_entry <- paste0(
+    "https://gisco-services.ec.europa.eu/pub/healthcare",
+    "/gpkg/EU.gpkg"
+  )
   filename <- basename(api_entry)
 
 
